import { openBlock, createElementBlock, normalizeStyle, normalizeClass, renderSlot, toDisplayString, createCommentVNode, createBlock, resolveDynamicComponent, mergeProps } from 'vue';
import { ObjectUtils, RowStatus } from 'primevue/utils';
import dayjs from 'dayjs';

function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function NumberFormat(value, format) {
  var formatType = _typeof(format);
  var locale = 'zh-Hans-CN';
  var style = 'decimal';
  var currency = 'CNY';
  var currencyDisplay = 'symbol';
  var useGrouping = true;
  var maximumFractionDigits = 2;
  var minimumFractionDigits = 2;
  if (format === null || format === '') return value;
  if (typeof value === 'string') {
    value = Number.parseFloat(value);
    if (Number.isNaN(value)) return 'NaN';
  }
  if (formatType === 'object') {
    var _formater = new Intl.NumberFormat(locale, format);
    return _formater.format(value || 0);
  }
  if (formatType === 'string') {
    //如果是货币格式，在前面加货币代码
    var _index = format.indexOf(":");
    if (_index > 0) {
      currency = format.substring(0, _index).toUpperCase().trim();
      format = format.substring(_index + 1);
      style = 'currency';
    } else if (format.endsWith("%")) {
      style = "percent";
      format = format.substring(0, format.length - 1);
    }
  }
  if (format.indexOf(",") <= 0) {
    useGrouping = false;
  }
  if (currency === 'RMB' || currency === '￥') {
    currency = 'CNY';
  } else if (currency === '$') {
    currency = 'USD';
  }
  if (format === '0') {
    minimumFractionDigits = 0;
    maximumFractionDigits = 0;
  } else if (format === '#,##0' || format === '#,###') {
    if (format === '#,###' && !value) return "";
    minimumFractionDigits = 0;
    maximumFractionDigits = 0;
  } else if (format === '#,##0.00') {
    minimumFractionDigits = 2;
    maximumFractionDigits = 2;
  } else if (format === '#,##0.00##') {
    minimumFractionDigits = 2;
    maximumFractionDigits = 4;
  } else {
    var index = format.indexOf(".");
    if (index <= 0) {
      minimumFractionDigits = 0;
      maximumFractionDigits = 0;
    } else {
      var decimal = format.substring(index + 1);
      minimumFractionDigits = decimal.indexOf("#");
      maximumFractionDigits = decimal.length;
      if (minimumFractionDigits < 0) {
        minimumFractionDigits = maximumFractionDigits;
      }
    }
  }
  var formater = new Intl.NumberFormat(locale, {
    style: style,
    currency: currency,
    currencyDisplay: currencyDisplay,
    useGrouping: useGrouping,
    maximumFractionDigits: maximumFractionDigits,
    minimumFractionDigits: minimumFractionDigits
  });
  return formater.format(value || 0);
}
function DateTimeFormat(value, format) {
  if (value === null || value === undefined || value === '') return "";
  return dayjs(value).format(format);
}

var script = {
  name: 'FormItem',
  props: {
    editor: {
      type: String,
      "default": null
    },
    field: {
      type: String,
      "default": null
    },
    colType: {
      type: String,
      "default": null
    },
    initial: {
      type: null,
      "default": null
    },
    label: {
      type: String,
      "default": ''
    },
    labelWidth: {
      type: [String, Number],
      "default": null
    },
    suffix: {
      type: String,
      "default": ''
    },
    required: {
      type: Boolean,
      "default": false
    },
    disabled: {
      type: [Boolean, String, Function],
      "default": null
    },
    readonly: {
      type: [Boolean, String, Function],
      "default": null
    },
    error: {
      type: String,
      "default": ''
    },
    align: {
      type: String,
      "default": null
    },
    className: {
      type: String,
      "default": null
    },
    style: {
      type: null,
      "default": null
    },
    cols: {
      type: [Number, String],
      "default": 0
    },
    offset: {
      type: [Number, String],
      "default": 0
    },
    format: {
      type: [String, Function, Object],
      "default": null
    }
  },
  inject: {
    $parentInstance: {
      "default": null
    }
  },
  data: function data() {
    return {};
  },
  methods: {
    onUpdateModelValue: function onUpdateModelValue(value) {
      this.$parentInstance && this.$parentInstance.onItemChange({
        rowData: this.$parentInstance.primaryData,
        field: this.field,
        value: value
      });
    },
    resolveFieldData: function resolveFieldData() {
      var value = ObjectUtils.resolveFieldData(this.primaryData, this.field);
      if (this.$attrs['codeTable']) {
        var options = this.$attrs['codeTable'];
        var optionValue = this.$attrs['optionValue'] || '';
        var optionLabel = this.$attrs['optionLabel'] || '';
        if (options && options.length) {
          return this.getOptionLabel(value, options, optionValue, optionLabel);
        }
      }
      var format = this.format || '';
      if (format) {
        if (typeof format === 'function') {
          return format(value);
        } else if (value instanceof Date || typeof value === "string" && new Date(value) instanceof Date) {
          return DateTimeFormat(value, format);
        }
        return NumberFormat(value, format);
      }
      return value;
    },
    getOptionLabel: function getOptionLabel(value, options, optionValue, optionLabel) {
      if (options.length <= 0) return value;
      var option = options[0];
      if (!optionLabel && option.hasOwnProperty("name")) {
        optionLabel = "name";
      } else if (!optionLabel && option.hasOwnProperty("label")) {
        optionLabel = "label";
      } else if (!optionLabel && option.hasOwnProperty("value")) {
        optionLabel = "value";
      }
      if (!optionValue && option.hasOwnProperty("code")) {
        optionValue = "code";
      } else if (!optionValue && option.hasOwnProperty("id")) {
        optionValue = "id";
      } else if (!optionValue && option.hasOwnProperty("guid")) {
        optionValue = "guid";
      } else if (!optionValue && option.hasOwnProperty("value")) {
        optionValue = "value";
      }
      option = options.find(function (item) {
        return item[optionValue] === value;
      });
      return option ? option[optionLabel] : value;
    }
  },
  computed: {
    primaryData: function primaryData() {
      var data = this.$parentInstance && this.$parentInstance.primaryData;
      return data || {};
    },
    containerClass: function containerClass() {
      var colClass = this.cols > 0 ? 'col-' + this.cols : null;
      var offsetClass = this.offset > 0 ? 'col-offset-' + this.offset : null;
      return [colClass, offsetClass, 'form-item'];
    },
    containerStyle: function containerStyle() {
      var style = this.style;
      if (typeof style === 'cls') {
        style = bodyStyle(this.primaryData, this.field);
      }
      return style;
    },
    showLabel: function showLabel() {
      var tagName = this.editor;
      return !this.label || tagName === 'Checkbox' || tagName === 'RadioButton' || tagName === 'TriStateCheckbox' ? false : true;
    },
    labelClass: function labelClass() {
      return ["form-item-label", {
        'required': this.required
      }];
    },
    dataClass: function dataClass() {
      var alignClass = this.align ? 'text-' + this.align : null;
      var disabledClass = this.disabled ? 'p-disabled' : null;
      return [this.className, disabledClass, alignClass, 'p-inputtext', 'p-component', 'form-item-content'];
    },
    labelWidthStyle: function labelWidthStyle() {
      var width = this.labelWidth ? this.labelWidth : this.$parentInstance ? this.$parentInstance.labelWidth : null;
      return width ? ["width: ".concat(width)] : null;
    },
    isDisabled: function isDisabled() {
      if (!this.$parentInstance || !this.$parentInstance.primaryData) return false;
      if (this.$parentInstance.disabled) return true;
      var data = this.primaryData;
      if (this.disabled === null || this.disabled === undefined || this.disabled === '') return false;else if (typeof this.disabled === 'boolean') return this.disabled;else if (typeof this.disabled === 'function') return this.disabled(data, this.field);else if (this.disabled === 'notnew') {
        var status = data['rowStatus'];
        return status === RowStatus.New || status === RowStatus.NewModified ? false : true;
      }
      return this.disabled === '1' ? true : false;
    },
    isReadonly: function isReadonly() {
      if (!this.$parentInstance || !this.$parentInstance.primaryData || this.$parentInstance.readonly) return true;
      var data = this.primaryData;
      if (this.readonly === null || this.readonly === undefined || this.readonly === '') return false;else if (typeof this.readonly === 'boolean') return this.readonly;else if (typeof this.readonly === 'function') return this.readonly(data, this.field);else if (this.readonly === 'notnew') {
        var status = data['rowStatus'];
        return status === RowStatus.New || status === RowStatus.NewModified ? false : true;
      }
      return this.readonly === '1' ? true : false;
    }
  }
};

var _hoisted_1 = ["data-field"];
var _hoisted_2 = {
  key: 0,
  "class": "form-item-suffix"
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", {
    style: normalizeStyle($options.containerStyle),
    "class": normalizeClass($options.containerClass),
    "data-field": $props.field
  }, [renderSlot(_ctx.$slots, "label", {}, function () {
    return [$options.showLabel ? (openBlock(), createElementBlock("label", {
      key: 0,
      "class": normalizeClass($options.labelClass),
      style: normalizeStyle($options.labelWidthStyle)
    }, toDisplayString($props.label), 7 /* TEXT, CLASS, STYLE */)) : createCommentVNode("v-if", true)];
  }), renderSlot(_ctx.$slots, "default", {
    primaryData: $options.primaryData,
    field: $props.field,
    disabled: $options.isDisabled,
    readonly: $options.isReadonly,
    "onUpdate:modelValue": _cache[0] || (_cache[0] = function () {
      return $options.onUpdateModelValue && $options.onUpdateModelValue.apply($options, arguments);
    })
  }, function () {
    return [$props.field && $props.editor ? (openBlock(), createBlock(resolveDynamicComponent($props.editor), mergeProps({
      key: 0,
      modelValue: $options.primaryData[$props.field],
      "onUpdate:modelValue": _cache[1] || (_cache[1] = function ($event) {
        return $options.primaryData[$props.field] = $event;
      }),
      "class": [$props.className, {
        'form-item-content': $props.editor !== 'InputSwitch'
      }]
    }, _ctx.$attrs, {
      align: $props.align,
      label: $props.label,
      disabled: $options.isDisabled,
      readonly: $options.isReadonly,
      "onUpdate:modelValue": $options.onUpdateModelValue
    }), null, 16 /* FULL_PROPS */, ["modelValue", "class", "align", "label", "disabled", "readonly", "onUpdate:modelValue"])) : (openBlock(), createElementBlock("div", {
      key: 1,
      "class": normalizeClass($options.dataClass)
    }, toDisplayString($options.resolveFieldData()), 3 /* TEXT, CLASS */))];
  }), renderSlot(_ctx.$slots, "suffix", {}, function () {
    return [$props.suffix ? (openBlock(), createElementBlock("span", _hoisted_2, toDisplayString($props.suffix), 1 /* TEXT */)) : createCommentVNode("v-if", true)];
  })], 14 /* CLASS, STYLE, PROPS */, _hoisted_1);
}

script.render = render;
script.__file = "components/lib/formitem/FormItem.vue";

export { script as default };
